@@ -1,23 +1,23 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
+"""Tests on the svgis command line tool"""
 # This file is part of svgis.
 # https://github.com/fitnr/svgis
-
 # Licensed under the GNU General Public License v3 (GPLv3) license:
 # http://opensource.org/licenses/GPL-3.0
 # Copyright (c) 2015-16, Neil Freeman <contact@fakeisthenewreal.org>
-
-import unittest
-import sys
-import os
+# pylint: disable=duplicate-code
 import io
+import os
 import re
+import sys
+import unittest
 from xml.dom import minidom
-import fiona.errors
-import click.testing
-import svgis.cli
 
+import click.testing
+import fiona.errors
+
+import svgis.cli
 
 PROJECTION = '+proj=lcc +lat_1=20 +lat_2=60 +lat_0=40 +lon_0=-96 +x_0=0 +y_0=0 +datum=NAD83 +units=m +no_defs'
 BOUNDS = (-124.0, 20.5, -64.0, 49.0)
@@ -25,10 +25,10 @@ BOUNDS = (-124.0, 20.5, -64.0, 49.0)
 
 class CliTestCase(unittest.TestCase):
     runner = click.testing.CliRunner()
-    fixture = 'tests/test_data/test.svg'
+    fixture = 'tests/fixtures/test.svg'
 
-    shp = 'tests/test_data/cb_2014_us_nation_20m.json'
-    dc = 'tests/test_data/tl_2015_11_place.json'
+    shp = 'tests/fixtures/cb_2014_us_nation_20m.json'
+    dc = 'tests/fixtures/tl_2015_11_place.json'
     css = 'polygon{fill:green}'
 
     def setUp(self):
@@ -64,7 +64,7 @@ class CliTestCase(unittest.TestCase):
 
     def testSvgProjectUtm(self):
         p = self.invoke(['project', '--method', 'utm', '--', '-110.277906', '35.450777', '-110.000477', '35.649030'])
-        expected = set('+proj=utm +zone=12 +datum=WGS84 +units=m +no_defs'.split(' '))
+        expected = set('+proj=utm +zone=12 +datum=WGS84 +units=m +no_defs +type=crs'.split(' '))
         self.assertSetEqual(set(p.output.strip().split(' ')), expected)
 
     def testSvgProject(self):
@@ -72,15 +72,29 @@ class CliTestCase(unittest.TestCase):
 
         self.assertEqual(p.exit_code, 0)
 
-        expected = set(u'+proj=lcc +lon_0=-111.0 +lat_1=35.64903 +lat_2=35.450777 '
-                       '+lat_0 +y_0=0 +ellps=GRS80 '
-                       '+towgs84 +no_defs'.split(' '))
-
+        expected = set(
+            [
+                '+type=crs',
+                '+lat_0=35.64903',
+                '+x_0=0',
+                '+units=m',
+                '+lon_0=-111',
+                '+towgs84=0,0,0,0,0,0,0',
+                '+y_0=0',
+                '+lat_1=35.64903',
+                '+proj=lcc',
+                '+no_defs',
+                '+lat_2=35.450777',
+                '+ellps=GRS80',
+            ]
+        )
         self.assertSetEqual(set(p.output.strip().split(' ')), expected)
 
     def testCliDraw(self):
-        self.invoke(['draw', '--crs', PROJECTION, '--scale', '1000', self.shp,
-                     '-o', 'tmp.svg', '--viewbox', '--bounds'] + [str(b) for b in BOUNDS])
+        self.invoke(
+            ['draw', '--crs', PROJECTION, '--scale', '1000', self.shp, '-o', 'tmp.svg', '--viewbox', '--bounds']
+            + [str(b) for b in BOUNDS]
+        )
 
         try:
             result = minidom.parse('tmp.svg').getElementsByTagName('svg').item(0)
@@ -91,7 +105,7 @@ class CliTestCase(unittest.TestCase):
             fixture_vb = [float(x) for x in fixture.attributes.get('viewBox').value.split(',')]
 
             for r, f in zip(result_vb, fixture_vb):
-                self.assertAlmostEqual(r, f, 5)
+                self.assertAlmostEqual(r, f, 5, 'viewbox doesnt match fixture')
 
         finally:
             os.remove('tmp.svg')
